@@ -42,9 +42,9 @@ class latin_design:
             lines.append(LineString([(minx + x * dx, miny), (minx + x * dx, maxy)]))
         for y in range(num_tiles + 1):
             lines.append(LineString([(minx, miny + y * dy), (maxx, miny + y * dy)]))
-        self.plot = gpd.GeoDataFrame(geometry=gpd.GeoSeries(polygonize(unary_union(MultiLineString(lines))))).iloc[[1,3,4,5,7]]
-        if self.plot.crs == None:
-            self.plot.crs = {'init': 'epsg:3857'}
+        self.geodesign = gpd.GeoDataFrame(geometry=gpd.GeoSeries(polygonize(unary_union(MultiLineString(lines))))).iloc[[1,3,4,5,7]]
+        if self.geodesign.crs == None:
+            self.geodesign.crs = {'init': 'epsg:3857'}
 
 class select_geoms:
     
@@ -194,30 +194,30 @@ class composite_union:
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(0.0005)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
-            self.geosolution = unary_data
-            if self.geosolution.crs == None:
-                self.geosolution.crs = data.crs
-            self.centroid = self.geosolution.centroid
+            self.geodesign = unary_data
+            if self.geodesign.crs == None:
+                self.geodesign.crs = data.crs
+            self.centroid = self.geodesign.centroid
             
         elif data.crs == {'init': 'epsg: 3857'} and buffer == None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(50)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
-            self.geosolution = unary_data
-            if self.geosolution.crs == None:
-                self.geosolution.crs = data.crs
-            self.centroid = self.geosolution.centroid
+            self.geodesign = unary_data
+            if self.geodesign.crs == None:
+                self.geodesign.crs = data.crs
+            self.centroid = self.geodesign.centroid
             
         elif buffer is not None and data.crs != None:
             unary_data = gpd.GeoDataFrame(
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(self.buffer)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
-            self.geosolution = unary_data
-            if self.geosolution.crs == None:
-                self.geosolution.crs = data.crs
-            self.centroid = self.geosolution.centroid
+            self.geodesign = unary_data
+            if self.geodesign.crs == None:
+                self.geodesign.crs = data.crs
+            self.centroid = self.geodesign.centroid
             
         elif buffer is not None and data.crs == None:
             data.crs = {'init': 'epsg:4326'}
@@ -225,13 +225,13 @@ class composite_union:
                 geometry=gpd.GeoSeries(unary_union(data.geometry).intersection(
                     unary_union(data.geometry).buffer(0.005)))).explode().reset_index().drop(['level_0', 'level_1'],
                                                                                               axis = 1)
-            self.geosolution = unary_data
-            if self.geosolution.crs == None:
-                self.geosolution.crs = data.crs
-            self.centroid = self.geosolution.centroid
+            self.geodesign = unary_data
+            if self.geodesign.crs == None:
+                self.geodesign.crs = data.crs
+            self.centroid = self.geodesign.centroid
             
         else:
-            self.geosolution = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])))
+            self.geodesign = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])))
             self.centroid = gpd.GeoDataFrame(geometry=gpd.GeoSeries(Polygon(unary_union(data.geometry).exterior.coords[:])).centroid)
 
 class check_topology:
